==> five.grok-1.1.tar.gz: five.grok-1.1/src/five/grok/interfaces.py <==
#############################################################################
#
# Copyright (c) 2009 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import grokcore.annotation.interfaces
import grokcore.component.interfaces
import grokcore.security.interfaces
import grokcore.site.interfaces
import grokcore.view.interfaces
import grokcore.viewlet.interfaces
import grokcore.formlib.interfaces


class IFiveGrokView(grokcore.view.interfaces.IGrokView):
    """A five.grok view is a specific implementation of a
    grokcore.view.View.
    """


class IFiveGrokAPI(grokcore.annotation.interfaces.IGrokcoreAnnotationAPI,
                   grokcore.component.interfaces.IGrokcoreComponentAPI,
                   grokcore.security.interfaces.IGrokcoreSecurityAPI,
                   grokcore.site.interfaces.IGrokcoreSiteAPI,
                   grokcore.view.interfaces.IGrokcoreViewAPI,
                   grokcore.viewlet.interfaces.IGrokcoreViewletAPI,
                   grokcore.formlib.interfaces.IGrokcoreFormlibAPI):
    """Official five.grok API.
    """

==> five.grok-1.3.1.tar.gz: five.grok-1.3.1/src/five/grok/interfaces.py <==
#############################################################################
#
# Copyright (c) 2009 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import grokcore.annotation.interfaces
import grokcore.component.interfaces
import grokcore.security.interfaces
import grokcore.site.interfaces
import grokcore.view.interfaces
import grokcore.viewlet.interfaces

def api(name):
    from zope.dottedname.resolve import resolve
    from zope.interface import Interface

    try:
        return True, resolve(name)
    except ImportError:
        return False, Interface


HAVE_FORMLIB, IGrokcoreFormlibAPI = api(
    'grokcore.formlib.interfaces.IGrokcoreFormlibAPI')


class IFiveGrokView(grokcore.view.interfaces.IGrokView):
    """A five.grok view is a specific implementation of a
    grokcore.view.View.
    """


class IFiveGrokAPI(grokcore.annotation.interfaces.IGrokcoreAnnotationAPI,
                   grokcore.component.interfaces.IGrokcoreComponentAPI,
                   grokcore.security.interfaces.IGrokcoreSecurityAPI,
                   grokcore.site.interfaces.IGrokcoreSiteAPI,
                   grokcore.view.interfaces.IGrokcoreViewAPI,
                   grokcore.viewlet.interfaces.IGrokcoreViewletAPI,
                   IGrokcoreFormlibAPI):
    """Official five.grok API.
    """
